# CMeel Boost

[![PyPI version](https://badge.fury.io/py/cmeel-boost.svg)](https://pypi.org/project/cmeel-boost)
[![Release](https://github.com/cmake-wheel/cmeel-boost/actions/workflows/release.yml/badge.svg)](https://github.com/cmake-wheel/cmeel-boost/actions/workflows/release.yml)
[![Build Status](https://api.cirrus-ci.com/github/cmake-wheel/cmeel-boost.svg)](https://cirrus-ci.com/github/cmake-wheel/cmeel-boost)

[Boost](https://www.boost.org/) distribution for cmeel packages.
